package com.ruoyi.web.controller.system;

import java.util.List;

import com.ruoyi.system.service.service.IApplyService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.Apply;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 申请Controller
 *
 * @author ruoyi
 * @date 2025-01-26
 */
@RestController
@RequestMapping("/system/apply")
public class ApplyController extends BaseController {
    @Autowired
    private IApplyService applyService;

    /**
     * 查询申请列表
     */
    @PreAuthorize("@ss.hasPermi('system:apply:list')")
    @GetMapping("/list")
    public TableDataInfo list(Apply apply) {
        startPage();
        if (getUserId() != 1) {
            apply.setUserId(getUserId());
        }
        List<Apply> list = applyService.selectApplyList(apply);
        return getDataTable(list);
    }

    /**
     * 获取申请详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:apply:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(applyService.selectApplyById(id));
    }

    /**
     * 新增申请
     */
    @PreAuthorize("@ss.hasPermi('system:apply:add')")
    @Log(title = "申请", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Apply apply) throws Exception {
        apply.setUserId(getUserId());
        return toAjax(applyService.insertApply(apply));
    }

    /**
     * 修改申请
     */
    @PreAuthorize("@ss.hasPermi('system:apply:edit')")
    @Log(title = "申请", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Apply apply) {
        return toAjax(applyService.updateApply(apply));
    }


}
