package com.ruoyi.web.controller.system;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.Perform;
import com.ruoyi.system.service.IPerformService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 演出Controller
 *
 * @author ruoyi
 * @date 2025-01-26
 */
@RestController
@RequestMapping("/system/perform")
public class PerformController extends BaseController {
    @Autowired
    private IPerformService performService;

    /**
     * 查询演出列表
     */
    @PreAuthorize("@ss.hasPermi('system:perform:list')")
    @GetMapping("/list")
    public TableDataInfo list(Perform perform) {
        startPage();
        List<Perform> list = performService.selectPerformList(perform);
        return getDataTable(list);
    }

    @GetMapping("/all")
    public AjaxResult getAll() {
        return success(performService.getAll());
    }

    /**
     * 导出演出列表
     */
    @PreAuthorize("@ss.hasPermi('system:perform:export')")
    @Log(title = "演出", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Perform perform) {
        List<Perform> list = performService.selectPerformList(perform);
        ExcelUtil<Perform> util = new ExcelUtil<Perform>(Perform.class);
        util.exportExcel(response, list, "演出数据");
    }

    /**
     * 获取演出详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:perform:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(performService.selectPerformById(id));
    }

    /**
     * 新增演出
     */
    @PreAuthorize("@ss.hasPermi('system:perform:add')")
    @Log(title = "演出", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Perform perform) throws Exception {
        return toAjax(performService.insertPerform(perform));
    }

    /**
     * 修改演出
     */
    @PreAuthorize("@ss.hasPermi('system:perform:edit')")
    @Log(title = "演出", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Perform perform) throws Exception {
        return toAjax(performService.updatePerform(perform));
    }

    /**
     * 删除演出
     */
    @PreAuthorize("@ss.hasPermi('system:perform:remove')")
    @Log(title = "演出", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(performService.deletePerformByIds(ids));
    }
}
