package com.ruoyi.system.service.impl;

import java.util.Date;
import java.util.List;

import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.PerformMapper;
import com.ruoyi.system.domain.Perform;
import com.ruoyi.system.service.IPerformService;

/**
 * 演出Service业务层处理
 *
 * @author ruoyi
 * @date 2025-01-26
 */
@Service
public class PerformServiceImpl implements IPerformService {
    @Autowired
    private PerformMapper performMapper;

    /**
     * 查询演出
     *
     * @param id 演出主键
     * @return 演出
     */
    @Override
    public Perform selectPerformById(Long id) {
        return performMapper.selectPerformById(id);
    }

    /**
     * 查询演出列表
     *
     * @param perform 演出
     * @return 演出
     */
    @Override
    public List<Perform> selectPerformList(Perform perform) {
        return performMapper.selectPerformList(perform);
    }

    /**
     * 查询演出列表
     *
     * @return 演出
     */
    @Override
    public List<Perform> getAll() {
        return performMapper.selectAll();
    }

    /**
     * 新增演出
     *
     * @param perform 演出
     * @return 结果
     */
    @Override
    public int insertPerform(Perform perform) throws Exception {
        if (perform.getStartTime().compareTo(new Date()) <= 0) {
            throw  new Exception("开始时间必须大于当前时间");
        }
        perform.setCreateTime(DateUtils.getNowDate());
        //未开始
        perform.setStatus("1");
        return performMapper.insertPerform(perform);
    }

    /**
     * 修改演出
     *
     * @param perform 演出
     * @return 结果
     */
    @Override
    public int updatePerform(Perform perform) throws Exception {
        if (perform.getStartTime().compareTo(new Date()) <= 0) {
            throw  new Exception("开始时间必须大于当前时间");
        }
        perform.setUpdateTime(DateUtils.getNowDate());
        return performMapper.updatePerform(perform);
    }

    /**
     * 批量删除演出
     *
     * @param ids 需要删除的演出主键
     * @return 结果
     */
    @Override
    public int deletePerformByIds(Long[] ids) {
        return performMapper.deletePerformByIds(ids);
    }

    /**
     * 删除演出信息
     *
     * @param id 演出主键
     * @return 结果
     */
    @Override
    public int deletePerformById(Long id) {
        return performMapper.deletePerformById(id);
    }
}
