package com.ruoyi.system.service.service.impl;

import java.util.List;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.system.mapper.PerformMapper;
import com.ruoyi.system.service.service.IApplyService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.ApplyMapper;
import com.ruoyi.system.domain.Apply;

/**
 * 申请Service业务层处理
 *
 * @author ruoyi
 * @date 2025-01-26
 */
@Service
public class ApplyServiceImpl implements IApplyService {
    @Autowired
    private ApplyMapper applyMapper;

    /**
     * 查询申请
     *
     * @param id 申请主键
     * @return 申请
     */
    @Override
    public Apply selectApplyById(Long id) {
        return applyMapper.selectApplyById(id);
    }

    /**
     * 查询申请列表
     *
     * @param apply 申请
     * @return 申请
     */
    @Override
    public List<Apply> selectApplyList(Apply apply) {
        return applyMapper.selectApplyList(apply);
    }

    /**
     * 新增申请
     *
     * @param apply 申请
     * @return 结果
     */
    @Override
    public int insertApply(Apply apply) throws Exception {
        Apply a = applyMapper.selectApplyPerform(apply);
        if(a !=null){
            throw new Exception("该团您已经申请过，请勿重复申请");
        }
        apply.setCreateTime(DateUtils.getNowDate());
        apply.setWeverseEmail(apply.getWeverseEmail().trim());
        apply.setWeversePassword(apply.getWeversePassword().trim());
        apply.setBirthday(apply.getBirthday().trim());
        apply.setCountryCode(apply.getCountryCode().trim());
        apply.setPhoneNum(apply.getPhoneNum().trim());
        apply.setWechatNum(apply.getWechatNum().trim());
        apply.setStatus("0");
        return applyMapper.insertApply(apply);
    }

    /**
     * 修改申请
     *
     * @param apply 申请
     * @return 结果
     */
    @Override
    public int updateApply(Apply apply) {
        apply.setUpdateTime(DateUtils.getNowDate());
        return applyMapper.updateApply(apply);
    }

    /**
     * 批量删除申请
     *
     * @param ids 需要删除的申请主键
     * @return 结果
     */
    @Override
    public int deleteApplyByIds(Long[] ids) {
        return applyMapper.deleteApplyByIds(ids);
    }

    /**
     * 删除申请信息
     *
     * @param id 申请主键
     * @return 结果
     */
    @Override
    public int deleteApplyById(Long id) {
        return applyMapper.deleteApplyById(id);
    }
}
